@@ -3,36 +3,16 @@
 
 name = "uds"
 
-
-from uds.uds_configuration.Config import Config
-
 from uds.uds_communications.Utilities.iResettableTimer import iResettableTimer
 from uds.uds_communications.Utilities.ResettableTimer import ResettableTimer
 from uds.uds_communications.Utilities.UtilityFunctions import fillArray
 
 # CAN Imports
-from uds.uds_communications.TransportProtocols.iTp import iTp
 from uds.uds_communications.TransportProtocols.Can import CanTpTypes
-from uds.uds_communications.TransportProtocols.Can.CanConnectionFactory import (
-    CanConnectionFactory,
-)
-from uds.uds_communications.TransportProtocols.Can.CanConnection import (
-    CanConnection,
-)
 from uds.uds_communications.TransportProtocols.Can.CanTp import CanTp
 
-# LIN imports
-from uds.uds_communications.TransportProtocols.Lin import LinTpTypes
-from uds.uds_communications.TransportProtocols.Lin.LinTp import LinTp
-
-# Test Transport Protocol
-from uds.uds_communications.TransportProtocols.Test.TestTp import TestTp
-
-# Transport Protocol factory
-from uds.uds_communications.TransportProtocols.TpFactory import TpFactory
-
 # Uds-Config tool imports
-from uds.uds_config_tool.UdsConfigTool import createUdsConnection
+from uds.uds_config_tool.UdsConfigTool import UdsTool
 from uds.uds_config_tool import (
     DecodeFunctions,
     FunctionCreation,
@@ -49,3 +29,7 @@ from uds.uds_config_tool.ISOStandard.ISOStandard import (
 
 # main uds import
 from uds.uds_communications.Uds.Uds import Uds
+
+from uds.config import Config
+from uds.interfaces import TpInterface
+from uds.factories import TpFactory
